@@ -5,16 +5,16 @@
 # This file is part of weboob.
 #
 # weboob is free software: you can redistribute it and/or modify
-# it under the terms of the GNU Lesser General Public License as published by
+# it under the terms of the GNU Affero General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
 #
 # weboob is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Lesser General Public License for more details.
+# GNU Affero General Public License for more details.
 #
-# You should have received a copy of the GNU Lesser General Public License
+# You should have received a copy of the GNU Affero General Public License
 # along with weboob. If not, see <http://www.gnu.org/licenses/>.
 
 import os
@@ -427,13 +427,11 @@ class Result(QFrame):
             backend_name = None
         for backend in self.weboob.iter_backends():
             if backend.has_caps(cap) and ((backend_name and backend.name == backend_name) or not backend_name):
-                object = getattr(backend, 'get_%s' % stype)(id)
+                exec('object = backend.get_%s(id)' % (stype))
                 if object:
-                    func_name = 'display' + stype[0].upper() + stype[1:]
-                    func = getattr(self, func_name)
-                    title = getattr(object, title_field)
-                    self.doAction('Details of %s %r' % (stype, title), func, [object, backend])
-
+                    func_display = 'self.display' + stype[0].upper() + stype[1:]
+                    exec("self.doAction('Details of %s \"%%s\"' %% object.%s, %s, [object, backend])" %
+                            (stype, title_field, func_display))
         QApplication.restoreOverrideCursor()
 
 
