@@ -130,9 +130,7 @@ class Repository(object):
         self.local = None
         self.signed = False
         self.key_update = 0
-        self.obsolete = False
         self.logger = getLogger('repository')
-        self.errors = {}
 
         self.modules = {}
 
@@ -167,17 +165,15 @@ class Repository(object):
         :param repo_path: path to save the downloaded index file.
         :type repo_path: str
         """
-        built = False
         if self.local:
             # Repository is local, open the file.
             filename = os.path.join(self.localurl2path(), self.INDEX)
             try:
                 fp = open(filename, 'r')
-            except IOError:
+            except IOError as e:
                 # This local repository doesn't contain a built modules.list index.
                 self.name = Repositories.url2filename(self.url)
                 self.build_index(self.localurl2path(), filename)
-                built = True
                 fp = open(filename, 'r')
         else:
             # This is a remote repository, download file
@@ -188,8 +184,7 @@ class Repository(object):
 
         self.parse_index(fp)
 
-        # this value can be changed by parse_index
-        if self.local and not built:
+        if self.local:
             # Always rebuild index of a local repository.
             self.build_index(self.localurl2path(), filename)
 
@@ -242,7 +237,6 @@ class Repository(object):
             self.maintainer = items['maintainer']
             self.signed = bool(int(items.get('signed', '0')))
             self.key_update = int(items.get('key_update', '0'))
-            self.obsolete = bool(int(items.get('obsolete', '0')))
         except KeyError as e:
             raise RepositoryUnavailable('Missing global parameters in repository: %s' % e)
         except ValueError as e:
@@ -277,9 +271,8 @@ class Repository(object):
         :param filename: file to save index
         :type filename: str
         """
-        self.logger.debug('Rebuild index')
+        print('Rebuild index')
         self.modules.clear()
-        self.errors.clear()
 
         if os.path.isdir(os.path.join(path, self.KEYDIR)):
             self.signed = True
@@ -290,7 +283,7 @@ class Repository(object):
 
         for name in sorted(os.listdir(path)):
             module_path = os.path.join(path, name)
-            if not os.path.isdir(module_path) or '.' in name or name == self.KEYDIR or not os.path.exists(os.path.join(module_path, '__init__.py')):
+            if not os.path.isdir(module_path) or '.' in name or name == self.KEYDIR:
                 continue
 
             try:
@@ -301,10 +294,8 @@ class Repository(object):
                     if fp:
                         fp.close()
             except Exception as e:
-                self.logger.warning('Unable to build module %s: [%s] %s' % (name, type(e).__name__, e))
-                bt = get_backtrace(e)
-                self.logger.debug(bt)
-                self.errors[name] = bt
+                print('Unable to build module %s: [%s] %s' % (name, type(e).__name__, e), file=sys.stderr)
+                self.logger.debug(get_backtrace(e))
             else:
                 m = ModuleInfo(module.name)
                 m.version = self.get_tree_mtime(module_path)
@@ -481,14 +472,11 @@ class Repositories(object):
     def load_browser(self):
         from weboob.browser.browsers import Browser
         from weboob.browser.profiles import Weboob as WeboobProfile
-        from weboob.tools.compat import getproxies
 
         class WeboobBrowser(Browser):
             PROFILE = WeboobProfile(self.version)
         if self.browser is None:
-            self.browser = WeboobBrowser(
-                logger=getLogger('browser', parent=self.logger),
-                proxy=getproxies())
+            self.browser = WeboobBrowser()
 
     def create_dir(self, name):
         if not os.path.exists(name):
@@ -619,10 +607,6 @@ class Repositories(object):
                 progress.error('Unable to load repository: %s' % e)
             else:
                 self.repositories.append(repository)
-                if repository.obsolete:
-                    last_update = datetime.strptime(str(repository.update), '%Y%m%d%H%M').strftime('%Y-%m-%d')
-                    progress.error('This repository does not receive updates anymore (since %s).\n'
-                                   'Your weboob version is probably obsolete and should be upgraded.' % last_update)
 
     def check_repositories(self):
         """
@@ -752,17 +736,6 @@ class Repositories(object):
         """
         return ''.join([l if l.isalnum() else '_' for l in url])
 
-    def __iter__(self):
-        for repository in self.repositories:
-            yield repository
-
-    @property
-    def errors(self):
-        errors = {}
-        for repository in self:
-            errors.update(repository.errors)
-        return errors
-
 
 class InvalidSignature(Exception):
     def __init__(self, filename):
